#!/bin/bash
#
# Configure LTSP with an existing IP through an user-friendly interface.
#
# Author: Jordi "Txor" Casas Ríos <jordi.casas@opentrends.net>
#

# defaults
DEFAULT_IP="192.168.10.1"

# text
GREETER_TITLE="Configuració del servidor LTSP"
GREETER_TEXT="Voleu triar l'adreça IP de la xarxa dels clients de l'LTSP?\nPer defecte s'utilitzarà $DEFAULT_IP."
INTERFACE_TITLE="Escollir IP"
INTERFACE_TEXT="Quina adreça voleu utilitzar per la xarxa dels clients d'LTSP?"
INTERFACE_COL1="Selecció"
INTERFACE_COL2="Interfície"
INTERFACE_COL3="Adreça"
INFO_OK="S'ha configurat el servidor LTSP perquè escolti als clients a l'adreça "
INFO_KO="Alguna cosa ha fallat! Teniu el log a "
INFO_NOCONF="No s'han trobat els fitxers de configuració del LTSP!"
INFO_ABORT="Cancelat per l'usuari."
CONFIG_TEXT="Configurant el servidor LTSP..."

# functions
fetch_if ()
{
	S="0"
	IF_NAMES=(`find /sys/class/net/ -type l -exec file {} \; | grep -v virtual | cut -d ':' -f 1 | cut -d '/' -f 5`)
	for (( i = 0 ; i < ${#IF_NAMES[@]} ; i++ )) ; do echo -n " $S " ; echo -n "${IF_NAMES[$i]} " ; ip addr show dev ${IF_NAMES[$i]} | grep -m 1 "inet " |  sed -e 's/^[ \t]*//' | cut -d ' ' -f 2 ; done
}
write_conf ()
{
	if [ -f /srv/tftpboot/KIWI/config.default -a -f /srv/tftpboot/KIWI/lts.conf -a -f /srv/tftpboot/pxelinux.cfg/default.linkat4 -a -f /srv/tftpboot/KIWI/template/config.default -a -f /srv/tftpboot/KIWI/template/lts.conf -a -f /srv/tftpboot/KIWI/template/default.linkat4 ] ; then
		chattr -i /srv/tftpboot/KIWI/config.default
		chattr -i /srv/tftpboot/KIWI/lts.conf
		mv /srv/tftpboot/KIWI/config.default /srv/tftpboot/KIWI/config.default.bak
		mv /srv/tftpboot/KIWI/lts.conf /srv/tftpboot/KIWI/lts.conf.bak
		mv /srv/tftpboot/pxelinux.cfg/default.linkat4 /srv/tftpboot/pxelinux.cfg/default.linkat4.bak
		sed -e "s/__IP__/$1/g" /srv/tftpboot/KIWI/template/config.default > /srv/tftpboot/KIWI/config.default
		sed -e "s/__IP__/$1/g" /srv/tftpboot/KIWI/template/lts.conf > /srv/tftpboot/KIWI/lts.conf
		sed -e "s/__IP__/$1/g" /srv/tftpboot/KIWI/template/default.linkat4 > /srv/tftpboot/pxelinux.cfg/default.linkat4
		chattr +i /srv/tftpboot/KIWI/config.default
		chattr +i /srv/tftpboot/KIWI/lts.conf
		return 0
	else
		return 1
	fi
}

# main
IP=$DEFAULT_IP
zenity --question --title="$GREETER_TITLE" --text="$GREETER_TEXT"
if [ $? -eq 0 ]; then
	LIST=`fetch_if`
	INTERFACE=$(zenity --title="$INTERFACE_TITLE" --text="$INTERFACE_TEXT" --list --column="$INTERFACE_COL1" --column="$INTERFACE_COL2" --column="$INTERFACE_COL3" --radiolist $LIST --print-column=ALL)
	if [ $? -eq 0 ]; then
		IP=$(echo $INTERFACE | cut -d '|' -f 2 | cut -d '/' -f 1) 
	else
		zenity --error --text="${INFO_ABORT}"
		exit 1
	fi
fi
write_conf $IP
if [ $? -eq 1 ]; then
	zenity --error --text="${INFO_NOCONF}"
	exit 1
fi
LOG=$(mktemp -t kiwi-ltsp-setup_logXXXX)
PIPE=$(mktemp -u)
mknod $PIPE p
cat $PIPE > $LOG &
cat $PIPE | zenity --progress --pulsate --auto-close --text="$CONFIG_TEXT" &
/usr/sbin/kiwi-ltsp-setup -c >$PIPE 2>&1
if [ $? -eq 0 ]; then
	zenity --info --text="${INFO_OK}${IP}."
	rm $LOG
else
	zenity --error --text="${INFO_KO}${LOG}."
	exit 1
fi
rm $PIPE
exit 0

